@@ -7,9 +7,9 @@ from multiprocessing.pool import Pool
 
 import click
 import humanize
-import requests
 from prettytable import PrettyTable
 
+from rebotics_sdk.advanced import remote_loaders
 from rebotics_sdk.cli.common import shell, configure, roles
 from .utils import ReboticsCLIContext, app_dir, pass_rebotics_context, read_saved_role, process_role
 from ..advanced.packers import ClassificationDatabasePacker, ClassificationDatabaseException
@@ -225,14 +225,12 @@ def set_retailer_url(ctx, retailer, url):
 
 def upload_packed(ctx, import_request, packed):
     destination = import_request['destination']
-    files = {
-        'file': ('features_backup.rcdb', packed)
-    }
 
     if ctx.verbose:
         click.echo("Sending the file to the S3 {}".format(destination))
 
-    response = requests.post(destination['url'], data=destination['fields'], files=files)
+    response = remote_loaders.upload(destination, packed, progress_bar=True)
+
     if response.status_code < 300:
         if ctx.verbose:
             click.echo("S3 {} response: {}".format(response.status_code, response.content))
@@ -260,8 +258,8 @@ def pack_and_import_classification_db(ctx, retailer, model, images, labels, feat
 \b
 db/
 ├── custom_folder
-│   ├── image_400x400_copy.png
-│   └── image_400x400.png
+│   ├── image_2.png
+│   └── image_1.png
 ├── features.txt
 └── labels.txt
 
@@ -271,7 +269,7 @@ admin pack-classification-db --features features.txt --labels labels.txt --image
 
 admin import_classification_db --retailer delta --model test_code classification.rcdb
     """
-    packer = ClassificationDatabasePacker(destination=None)
+    packer = ClassificationDatabasePacker(destination=None, progress_bar=True)
     if ctx.verbose:
         click.echo("Packing from provided values: \n"
                    "labels: {labels} \n"
@@ -337,8 +335,8 @@ def pack_classification_db(ctx, images, labels, features, target):
 \b
 db/
 ├── custom_folder
-│   ├── image_400x400_copy.png
-│   └── image_400x400.png
+│   ├── image_2.png
+│   └── image_1.png
 ├── features.txt
 └── labels.txt
 
@@ -348,11 +346,11 @@ db/
     """
     target = pathlib.Path(target)
     if target.is_dir():
-        target = target / "{}.{}".format(
-            datetime.datetime.now().strftime('%Y-%m-%dZ%H:%M'),
+        target = target / "classification_db{}.{}".format(
+            datetime.datetime.now().strftime('%Y-%m-%dZ%H%M'),
             ClassificationDatabasePacker.extension
         )
-    packer = ClassificationDatabasePacker(destination=target)
+    packer = ClassificationDatabasePacker(destination=target, progress_bar=True)
     if ctx.verbose:
         click.echo("Packing from provided values: \n"
                    "labels: {labels} \n"
