@@ -1,5 +1,6 @@
 import json
 import logging
+from copy import copy
 from pprint import pformat
 from time import sleep
 
@@ -185,18 +186,23 @@ def remote_service(path, headers=None, timeout=None, json=True, raw=False):
             if not isinstance(self, ReboticsBaseProvider):
                 raise TypeError('This decorator should be used only for subclasses Rebotics Base Providers')
 
-            authentication_headers = self.get_provider_headers()
+            provider = copy(self)
+
+            authentication_headers = provider.get_provider_headers()
             headers.update(authentication_headers)
 
-            session = ProviderRequestProxy(self.build_url(path),
+            session = ProviderRequestProxy(provider.build_url(path),
                                            headers,
-                                           timeout=timeout or self.timeout,
-                                           retries=self.retries,
+                                           timeout=timeout or provider.timeout,
+                                           retries=provider.retries,
                                            json=json,
                                            raw=raw,
-                                           host=self.host)
+                                           host=provider.host)
+
+            # FIXME: this fucking shit is not thread safe!!!!
+            provider.session = session
             self.session = session
-            return func(self, *args, **kwargs)
+            return func(provider, *args, **kwargs)
 
         return inner
 
@@ -262,6 +268,14 @@ class ReboticsBaseProvider(object):
             'role': self.role
         }))
 
+    def set_retailer_identifier(self, retailer_id, retailer_secret_key):
+        self.headers['x-retailer-id'] = retailer_id
+        self.headers['x-retailer-secret-key'] = retailer_secret_key
+
+    def is_retailer_identifier_used(self):
+        header_keys = self.headers.keys()
+        return 'x-retailer-id' in header_keys and 'x-retailer-secret-key' in header_keys
+
 
 class PageResult(object):
     def __init__(self, json_data):
